ZwergETL Basic Components
==========================

Basic components for ZwergETL framework.

This package includes the following components:

1. `CsvReader` - read csv files
2. `CsvWriter` - write csv files
3. `Dummy` - consume data from input port and optionally print it to stdout. Used for debugging ETL pipelines.
4. `HashCalc` - calculate hashes on specified fields on records coming on input port.
5. `Reformat` - perform user-defined calculations on records from input port.
